package de.itstall.model;

/**
 * Das Model für die Kontakte
 */
public class Kontakt {
	// region 0 Variables
	private String vorname, nachname, strasse, hausnummer, plz, ort, telefon = "";
	//endregion

	// region 1 Setter

	/**
	 * Setzt den Vornamen. Dieser darf maximal 50 Zeichen lang sein
	 * Gibt im erfolgs Fall true und bei einem Fehler false zurück
	 * @param vorname : String
	 * @return boolean
	 */
	public boolean setVorname(String vorname) {
		if (vorname  != null && vorname.length() <= 50) {
			this.vorname = vorname;
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Setzt den Nachnamen. Dieser darf maximal 50 Zeichen lang sein
	 * Gibt im erfolgs Fall true und bei einem Fehler false zurück
	 * @param nachname : String
	 * @return boolean
	 */
	public boolean setNachname(String nachname) {
		if (nachname  != null && nachname.length() <= 50) {
			this.nachname = nachname;
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Setzt die Straße. Diese darf maximal 50 Zeichen lang sein
	 * Gibt im erfolgs Fall true und bei einem Fehler false zurück
	 * @param strasse : String
	 * @return boolean
	 */
	public boolean setStrasse(String strasse) {
		if (strasse  != null && strasse.length() <= 50) {
			this.strasse = strasse;
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Setzt die Hausnummer. Diese darf maximal 10 Zeichen lang sein
	 * Gibt im erfolgs Fall true und bei einem Fehler false zurück
	 * @param hausnummer : String
	 * @return boolean
	 */
	public boolean setHausnummer(String hausnummer) {
		if (hausnummer != null && hausnummer.length() <= 10) {
			this.hausnummer = hausnummer;
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Setzt die Postleitzahl. Diese muss genau 5 Zeichen lang sein
	 * Gibt im erfolgs Fall true und bei einem Fehler false zurück
	 * @param plz : String
	 * @return boolean
	 */
	public boolean setPlz(String plz) {
		if (plz != null && plz.length() == 5) {
			this.plz = plz;
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Setzt den Ort. Dieser darf maximal 50 Zeichen lang sein
	 * Gibt im erfolgs Fall true und bei einem Fehler false zurück
	 * @param ort : String
	 * @return boolean
	 */
	public boolean setOrt(String ort) {
		if (ort != null && ort.length() <= 50) {
			this.ort = ort;
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Setzt die Telefonnummer. Diese muss zwischen 3 und 50 Zeichen lang sein
	 * Gibt im erfolgs Fall true und bei einem Fehler false zurück
	 * @param telefon : String
	 * @return boolean
	 */
	public boolean setTelefon(String telefon) {
		if (telefon != null && telefon.length() <= 30 && telefon.length() > 2 && isNumeric(telefon)) {
			this.telefon = telefon;
			return true;
		} else {
			return false;
		}
	}
	//endregion

	// region 2. Getter
	/**
	 * Gibt den Vornamen zurück
	 * @return : String
	 */
	public String getVorname() {
		return vorname;
	}

	/**
	 * Gibt den Nachnamen zurück
	 * @return : String
	 */
	public String getNachname() {
		return nachname;
	}

	/**
	 * Gibt die Straße zurück
	 * @return : String
	 */
	public String getStrasse() {
		return strasse;
	}

	/**
	 * Gibt die Hausnummer zurück
	 * @return : String
	 */
	public String getHausnummer() {
		return hausnummer;
	}

	/**
	 * Gibt die Postleitzahl zurück
	 * @return : String
	 */
	public String getPlz() {
		return plz;
	}

	/**
	 * Gibt den Ort zurück
	 * @return : String
	 */
	public String getOrt() {
		return ort;
	}

	/**
	 * Gibt die Telefonnummer zurück
	 * @return : String
	 */
	public String getTelefon() {
		return telefon;
	}
	//endregion

	//region 3 Functions
	/**
	 * Prueft ob der String ausschließlich aus Zahlen besteht
	 */
	public boolean isNumeric(String s) {
		return s != null && s.matches("[-+]?\\d*\\.?\\d+");
	}
	//endregion
}
